@@ -5,6 +5,9 @@ from pybliometrics.scopus.abstract_retrieval import *
 from pybliometrics.scopus.affiliation_retrieval import *
 from pybliometrics.scopus.affiliation_search import *
 from pybliometrics.scopus.author_retrieval import *
+from pybliometrics.scopus.plumx_metrics import *
 from pybliometrics.scopus.author_search import *
 from pybliometrics.scopus.scopus_search import *
+from pybliometrics.scopus.serial_search import *
 from pybliometrics.scopus.serial_title import *
+
