@@ -260,8 +260,13 @@ class AbstractRetrieval(Retrieval):
 
     @property
     def endingPage(self):
-        """Ending page."""
-        return chained_get(self._json, ['coredata', 'prism:endingPage'])
+        """Ending page. If this is empty, try .pageRange instead."""
+        # Try coredata first, fall back to head afterwards
+        ending = chained_get(self._json, ['coredata', 'prism:endingPage'])
+        if not ending:
+            path = ['source', 'volisspag', 'pagerange', '@last']
+            ending = chained_get(self._head, path)
+        return ending
 
     @property
     def funding(self):
@@ -339,10 +344,29 @@ class AbstractRetrieval(Retrieval):
         """Language of the article."""
         return chained_get(self._json, ['language', '@xml:lang'])
 
+    @property
+    def openaccess(self):
+        """The openaccess status encoded in single digits."""
+        return chained_get(self._json, ['coredata', 'openaccess'])
+
+    @property
+    def openaccessFlag(self):
+        """Whether the document is available via open access or not."""
+        flag = chained_get(self._json, ['coredata', 'openaccessFlag'])
+        if flag:
+            flag = flag == "true"
+        return flag
+
     @property
     def pageRange(self):
-        """Page range."""
-        return chained_get(self._json, ['coredata', 'prism:pageRange'])
+        """Page range.  If this is empty, try .startingPage and
+        .endingPage instead.
+        """
+        # Try data from coredata first, fall back to head afterwards
+        pages = chained_get(self._json, ['coredata', 'prism:pageRange'])
+        if not pages:
+            return chained_get(self._head, ['source', 'volisspag', 'pages'])
+        return pages
 
     @property
     def pii(self):
@@ -512,8 +536,13 @@ class AbstractRetrieval(Retrieval):
 
     @property
     def startingPage(self):
-        """Starting page."""
-        return chained_get(self._json, ['coredata', 'prism:startingPage'])
+        """Starting page.  If this is empty, try .pageRange instead."""
+        # Try coredata first, fall back to bibrecord afterwards
+        starting = chained_get(self._json, ['coredata', 'prism:startingPage'])
+        if not starting:
+            path = ['source', 'volisspag', 'pagerange', '@first']
+            starting = chained_get(self._head, path)
+        return starting
 
     @property
     def subject_areas(self):
@@ -625,6 +654,7 @@ class AbstractRetrieval(Retrieval):
         Assumes the document is a journal article and was loaded with
         view="META_ABS" or view="FULL".
         """
+        date = self.get_cache_file_mdate().split()[0]
         # Authors
         if self.authors:
             if len(self.authors) > 1:
@@ -635,16 +665,15 @@ class AbstractRetrieval(Retrieval):
         else:
             authors = "(No authors found)"
         # All other information
-        s = f'[[{self.scopus_link}][{self.eid}]]  {authors}, {self.title}, '\
-            f'{self.publicationName}, {self.volume}'
+        s = f'{authors}: "{self.title}", {self.publicationName}, {self.volume}'
         if self.issueIdentifier:
             s += f'({self.issueIdentifier})'
         s += ', '
         s += _parse_pages(self)
         s += f'({self.coverDate[:4]}).'
         if self.doi:
-            s += ' https://doi.org/{self.doi},'
-        s += f' {self.scopus_link}, cited {self.citedby_count} times (Scopus).'
+            s += f' https://doi.org/{self.doi}.\n'
+        s += f'{self.citedby_count} citations as of {date}'
         if self.affiliation:
             s += "\n  Affiliations:\n   "
             s += '\n   '.join([aff.name for aff in self.affiliation])
